@@ -75,7 +75,7 @@ use threads::shared;
 use Carp;
 use 5.8.0;
 
-our $VERSION = 1.1.2;
+our $VERSION = 1.1;
 
 my %instance;									####### Global instance which will be returned every time the constructor's called
 
@@ -122,9 +122,7 @@ my $_threadRun = sub {
 };
 
 my $usage = q/Usage: $obj = Threads::Pool->getInstance( [[ \&coderef_to_execute, <number_of_threads_you_want> ], thread_wait_time] )
-		 or: $obj = Threads::Pool->getInstance( { [[ code => \&coderef_to_execute, threads => <number_of_threads_you_want>, ] wait => thread_wait_time ] } )
-		 or: $obj = Threads::Pool->getInstance( { code => \&coderef_to_execute } )
-		 or: $obj = Threads::Pool->getInstance( \&coderef_to_execute )/;
+		 or: $obj = Threads::Pool->getInstance( { [[ code => \&coderef_to_execute, threads => <number_of_threads_you_want>, ] wait => thread_wait_time ] } )/;
 
 ### Constructor/Singleton as pool manager
 #   This is the only method provided to access the pool. The very first time, you must give the number of threads to be run, and the CODEREF 
@@ -349,28 +347,23 @@ sub destroy() {
 sub DESTROY {
 
 	my $self = shift;
-
+	
+	local $@;
 
 	for ( @{ $self->{ pool } } ) {
-			
-		if ( $threads::VERSION >= 1.27 ) {
 											
-			eval {
-												####### Just make sure everything gets tidy up before leaving
-				$_->kill('KILL');						####### if we make to catch up before the instance is gone. Note that this will
-												####### be invoked only when every reference contained in the class will be
-												####### destroied. Otherwise, perl will probably complain that you
-			};									####### still have running threads while exiting
+		eval {
+											####### Just make sure everything gets tidy up before leaving
+			$_->kill('KILL');						####### if we make to catch up before the instance is gone. Note that this will
+											####### be invoked only when every reference contained in the class will be
+											####### destroied. Otherwise, perl will probably complain that you
+		};									####### still have running threads while exiting
 
-		} else {
-			
-			eval {
+		eval {
 
-				$_->detach();							####### Try to detach, as last resort, if ever needed.
-			
-			};
+			$_->detach();							####### Try to detach, as last resort, if ever needed.
 		
-		}
+		};
 											
 	}									
 
